# vim: set sw=4 ts=4 et nu:
#
# spec file for package webrtc-audio-processing
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname      1
# Please submit bugfixes or comments via http://bugs.opensuse.org/
Name:           webrtc-audio-processing
Version:        0.3.1
Release:        1.18
Summary:        Real-Time Communication Library for Web Browsers
License:        BSD-3-Clause
Group:          System/Libraries
URL:            https://www.freedesktop.org/software/pulseaudio/webrtc-audio-processing/
Source:         http://freedesktop.org/software/pulseaudio/webrtc-audio-processing/webrtc-audio-processing-%{version}.tar.xz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAN big_endian_support.patch https://bugs.freedesktop.org/show_bug.cgi?id=95738
Patch1:         big_endian_support.patch
# PATCH-FIX-UPSTREAN big_endian_support.patch https://bugs.freedesktop.org/show_bug.cgi?id=95738
Patch2:         big_endian_support_2.patch
# PATCH-FIX-OPENSUSE webrtc-(ppc64|s390x|aarch64).patch
Patch100:       webrtc-ppc64.patch
Patch101:       webrtc-s390x.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  xz

%description
WebRTC is an open source project that enables web browsers with Real-Time
Communications (RTC) capabilities via simple Javascript APIs. The WebRTC
components have been optimized to best serve this purpose.

WebRTC implements the W3C's proposal for video conferencing on the web.

%package -n libwebrtc_audio_processing%{soname}
Summary:        Real-Time Communication Library for Web Browsers
Group:          System/Libraries

%description -n libwebrtc_audio_processing%{soname}
WebRTC is an open source project that enables web browsers with Real-Time
Communications (RTC) capabilities via simple Javascript APIs. The WebRTC
components have been optimized to best serve this purpose.

WebRTC implements the W3C's proposal for video conferencing on the web.

%package -n libwebrtc_audio_processing-devel
Summary:        Real-Time Communication Library for Web Browsers
Group:          Development/Libraries/C and C++
Requires:       libwebrtc_audio_processing%{soname} = %{version}

%description -n libwebrtc_audio_processing-devel
WebRTC is an open source project that enables web browsers with Real-Time
Communications (RTC) capabilities via simple Javascript APIs. The WebRTC
components have been optimized to best serve this purpose.

WebRTC implements the W3C's proposal for video conferencing on the web.

%package -n libwebrtc_audio_processing-devel-static
Summary:        Real-Time Communication Library for Web Browsers
Group:          Development/Libraries/C and C++
Requires:       libwebrtc_audio_processing-devel = %{version}

%description -n libwebrtc_audio_processing-devel-static
WebRTC is an open source project that enables web browsers with Real-Time
Communications (RTC) capabilities via simple Javascript APIs. The WebRTC
components have been optimized to best serve this purpose.

WebRTC implements the W3C's proposal for video conferencing on the web.

%prep
%setup -q -T -c "%{name}-%{version}"
xz --decompress --stdout "%{SOURCE0}" | tar xf - --strip-components=1
sed -i 's/\r$//' AUTHORS
%patch1 -p1
%patch2 -p1
%patch100
%patch101

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%configure
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libwebrtc_audio_processing%{soname} -p /sbin/ldconfig
%postun -n libwebrtc_audio_processing%{soname} -p /sbin/ldconfig

%files -n libwebrtc_audio_processing%{soname}
%license COPYING
%doc AUTHORS NEWS README.md UPDATING.md
%{_libdir}/libwebrtc_audio_processing.so.%{soname}
%{_libdir}/libwebrtc_audio_processing.so.%{soname}.*.*

%files -n libwebrtc_audio_processing-devel
%{_includedir}/webrtc_audio_processing
%{_libdir}/libwebrtc_audio_processing.so
%{_libdir}/pkgconfig/webrtc-audio-processing.pc

%files -n libwebrtc_audio_processing-devel-static
%{_libdir}/libwebrtc_audio_processing.a

%changelog
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.3.1:
  * doc: file invalid reference to pulseaudio mailing list
  * various build system fixes
- spec-cleaner run
* Fri Aug  2 2019 Martin Liška <mliska@suse.cz>
- Use FAT LTO objects in order to provide proper static library.
* Thu Jan 12 2017 olaf@aepfle.de
- Add baselibs.conf for gstreamer-plugins-bad-32bit
* Sat Jun 25 2016 oholecek@suse.com
- Remove webrtc-aarch64.patch, no longer needed
- Adapt the rest of webrtc- patches to new arch naming
* Thu Jun 23 2016 oholecek@suse.com
- Remove unneeded explicit version dependency for automake
* Wed Jun 22 2016 oholecek@suse.com
- Update to 0.3
  * build: enforce linking with --no-undefined, add explicit -lpthread
  * build: Make sure files with SSE2 code are compiled with -msse2
- Remove no-undefined.patch
- Remove webrtc-audio-processing-0.2-x86_msse2.patch
* Mon Jun 20 2016 oholecek@suse.com
- Add no-undefined.patch patch
  https://cgit.freedesktop.org/pulseaudio/webrtc-audio-processing/patch/?id=d58164e4d87854233564b59e76259b72e21507f6
- Add big_endian_support_2.patch  https://bugs.freedesktop.org/show_bug.cgi?id=95738
- Adapt webrtc-audio-processing-0.2-x86_msse2.patch to new version
- Adapt big_endian_support.patch to new version
* Mon May 30 2016 oholecek@suse.com
- Add webrtc-audio-processing-0.2-x86_msse2.patch patch fixing 386 build
  https://lists.freedesktop.org/archives/pulseaudio-discuss/2016-May/026294.html
- Add big_endian_support.patch
  https://bugs.freedesktop.org/show_bug.cgi?id=95738
- New automake version dependency >= 1.5
* Thu May 26 2016 oholecek@suse.com
- Update to 0.2:
  Contains API breaking changes.
  Upstream changes include:
  * Rewritten AGC and voice activity detection
  * Intelligibility enhancer
  * Extended AEC filter
  * Beamformer
  * Transient suppressor
  * ARM, NEON and MIPS optimisations (MIPS optimisations are not hooked up)
  API changes:
  * We no longer include a top-level audio_processing.h. The webrtc tree format
    is used, so use webrtc/modules/audio_processing/include/audio_processing.h
  * The top-level module_common_types.h has also been moved to
    webrtc/modules/interface/module_common_types.h
  * C++11 support is now required while compiling client code
  * AudioProcessing::Create() does not take any arguments any more
  * AudioProcessing::Destroy() is gone, use standard C++ "delete" instead
  * Stream parameters are now configured via StreamConfig and ProcessingConfig
    rather than set_sample_rate(), set_num_channels(), etc.
  * AudioFrame field names have changed
  * Use config API for newer audio processing options
  * Use ProcessReverseStream() instead of AnalyzeReverseStream(), particularly
    when using the intelligibility enhancer
  * GainControl::set_analog_level_limits() is broken. The AGC implementation
    hard codes 0-255 as the volume range
  Other notes:
  * The new audio processing parameters are not all tested, and a few are not
    enabled upstream (in Chromium) either
  * The rewritten AGC appears to be less sensitive, and it might make sense to
    initialise the capture volume to something reasonable (33%% or 50%%, for
    example) to make sure there is sufficient energy in the stream to trigger
    the AGC mechanism
- Adapted all 3 arch patches
* Thu Mar  7 2013 idonmez@suse.com
- Add patch webrtc-aarch64.patch from algraf to add aarch64 support
* Wed Dec 19 2012 ro@suse.de
- add s390 and s390x to known platforms
  by adding webrtc-s390x.patch
* Tue Jul  3 2012 dvaleev@suse.com
- add ppc64 to known platforms
* Tue May 15 2012 pascal.bleser@opensuse.org
- initial version (0.1)
